==> HinemosWebClient_src-2.0.1.tar.gz: HinemosWebClient_src-2.0.1/js/common/headerData.js <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/


/*******************************************************************************
 * Declare header
 */
var getHeaderData = function(){
	/***********************************************************************
	 * Header menu structure
	 */
	// Structure of a action click:
	//   [ele1, ele2]:
	//     els1: 
	//       0     : add a view to active perspective
	//       1     : open a dialog
	//       others: name of a function which belong to common cm
	
	return {
		/*Not used for version 1.0
		"${operationsM}": {
			 * "${common}": {
				"${dialog.notify.list}":
					[1, "notify.list"]
				,"${dialog.notify.mail.list}":
					[1, "notify.mail_list"]
				,"${dialog.logtransfer.list}":
					[1, "logtransfer.list"]
				,"${calendar}": {
					"${view.calenadr.list}":
						[0, "calendar.list"]
					,"${view.calenadr.weekday}":
						[0, "calendar.weekday"]
					,"${view.calenadr.add}":
						[0, "calendar.add"]
				}
				,"${accesscontrol}": {
					"${view.accesscontrol.user}":
						[0, "accesscontrol.user"]
				}
				,"${priority.judgment}": {
					"${dialog.priority.create.modify}":
						[1, "priority.modify"]
				}
				,"${repository}": {
					"${view.repository.node}":
						[0, "repository.node"]
					,"${view.repository.node.property}": 
						[0, "repository.node_property"]
					,"${view.repository.assigned.scopes}":
						[0, "repository.assigned_scopes"]
					,"${view.repository.scope}":
						[0, "repository.scope"]
				}
			}
			,"${collective.run}": {
				"${dialog.collective.run.create.change}":
					[0, "collective.run_create_change"]
				,"${view.collective.run.parameter}":
					[0, "collective.run_parameter"]
				,"${view.collective.run.history}":
					[0, "collective.run_history"]
				,"${view.collective.run.detail}":
					[0, "collective.run_detail"]
			}
			,"${monitor}": {*/
				/*Not used for version 1.0
				 * "${dialog.agent.list}":
					[1, "hinemosagent.list"]
				,"${dialog.http.list}":
					[1, "http.list"]
				,"${view.monitor.scope}":
					[0, "monitor.scope"]
				,"${view.monitor.status}":
					[0, "monitor.status"]
				,"${view.monitor.event}":
					[0, "monitor.event"]*/
				/*Not used for version 1.0
				 * ,"${dialog.performance.monitor.list}":
					[1, "performance.list"]
				,"${dialog.ping.list}":
					[1, "ping.list"]
				,"${dialog.port.list}":
					[1, "port.list"]
				,"${dialog.process.list}":
					[1, "process.list"]
				,"${dialog.snmp.list}":
					[1, "snmp.list"]
				,"${dialog.snmptrap.list}":
					[1, "snmptrap.list"]
				,"${dialog.sql.list}":
					[1, "sql.list"]
				,"${dialog.syslog-ng.list}":
					[1, "syslogng.list"]
			}*/
			/*Not used for version 1.0
			 * ,"${job.management}": {
					"${view.job.list}":
						[0, "job.list"]
					,"${view.job.history}":
						[0, "job.history"]
					,"${view.job.job.detail}":
						[0, "job.job_detail"]
					,"${view.job.node.detail}":
						[0, "job.node_detail"]
					,"${view.job.schedule}":
						[0, "job.schedule"]
					,"${view.job.run.schedule}":
						[0, "job.run_schedule"]
					,"${view.job.run.schedule.detail}":
						[0, "job.run_schedule_detail"]
					,"${view.job.forward.file}":
						[0, "job.forward_file"]
			}
			,"${maintenance}": {
				"${dialog.maintenance.list}":
					[1, "maintenance.list"]
			}
			,"${performance}": {
				"${view.performance.list}":
					[0, "performance.list"]
				,"${view.performance.recordedgraph}":
					[0, "performance.recordedgraph"]
				,"${view.performance.realtimegraph}":
					[0, "performance.realtimegraph"]
			}
		}*/
		/*Not used for version 1.0
		 * ,"${setupS}": {
			"${setup}":
				["openSetupDlg"]
		}
		,*/"${perspectiveP}": {
			"${open.perspective}":
				["openPersDlg"]
			/*Not used for version 1.0
			 * ,"${save.perspective}":
				["savePerspective"]*/
		}
		,"${accesscontrolA}": {
			"${accesscontrol.login}":
				["login"]
			,"${accesscontrol.logout}":
				["logout"]
		}
		,"${menu.help}": {
			"${menu.help.about.web}":
				["openHelpDlg"]
		}
	};
}

==> HinemosWebClient_src-2.0.2.tar.gz: HinemosWebClient_src-2.0.2/js/common/headerData.js <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/


/*******************************************************************************
 * Declare header
 */
var getHeaderData = function(){
	/***********************************************************************
	 * Header menu structure
	 */
	// Structure of a action click:
	//   [ele1, ele2]:
	//     els1: 
	//       0     : add a view to active perspective
	//       1     : open a dialog
	//       others: name of a function which belong to common cm
	
	return {
		/*Not used for version 1.0
		"${operationsM}": {
			 * "${common}": {
				"${dialog.notify.list}":
					[1, "notify.list"]
				,"${dialog.notify.mail.list}":
					[1, "notify.mail_list"]
				,"${dialog.logtransfer.list}":
					[1, "logtransfer.list"]
				,"${calendar}": {
					"${view.calenadr.list}":
						[0, "calendar.list"]
					,"${view.calenadr.weekday}":
						[0, "calendar.weekday"]
					,"${view.calenadr.add}":
						[0, "calendar.add"]
				}
				,"${accesscontrol}": {
					"${view.accesscontrol.user}":
						[0, "accesscontrol.user"]
				}
				,"${priority.judgment}": {
					"${dialog.priority.create.modify}":
						[1, "priority.modify"]
				}
				,"${repository}": {
					"${view.repository.node}":
						[0, "repository.node"]
					,"${view.repository.node.property}": 
						[0, "repository.node_property"]
					,"${view.repository.assigned.scopes}":
						[0, "repository.assigned_scopes"]
					,"${view.repository.scope}":
						[0, "repository.scope"]
				}
			}
			,"${collective.run}": {
				"${dialog.collective.run.create.change}":
					[0, "collective.run_create_change"]
				,"${view.collective.run.parameter}":
					[0, "collective.run_parameter"]
				,"${view.collective.run.history}":
					[0, "collective.run_history"]
				,"${view.collective.run.detail}":
					[0, "collective.run_detail"]
			}
			,"${monitor}": {*/
				/*Not used for version 1.0
				 * "${dialog.agent.list}":
					[1, "hinemosagent.list"]
				,"${dialog.http.list}":
					[1, "http.list"]
				,"${view.monitor.scope}":
					[0, "monitor.scope"]
				,"${view.monitor.status}":
					[0, "monitor.status"]
				,"${view.monitor.event}":
					[0, "monitor.event"]*/
				/*Not used for version 1.0
				 * ,"${dialog.performance.monitor.list}":
					[1, "performance.list"]
				,"${dialog.ping.list}":
					[1, "ping.list"]
				,"${dialog.port.list}":
					[1, "port.list"]
				,"${dialog.process.list}":
					[1, "process.list"]
				,"${dialog.snmp.list}":
					[1, "snmp.list"]
				,"${dialog.snmptrap.list}":
					[1, "snmptrap.list"]
				,"${dialog.sql.list}":
					[1, "sql.list"]
				,"${dialog.syslog-ng.list}":
					[1, "syslogng.list"]
			}*/
			/*Not used for version 1.0
			 * ,"${job.management}": {
					"${view.job.list}":
						[0, "job.list"]
					,"${view.job.history}":
						[0, "job.history"]
					,"${view.job.job.detail}":
						[0, "job.job_detail"]
					,"${view.job.node.detail}":
						[0, "job.node_detail"]
					,"${view.job.schedule}":
						[0, "job.schedule"]
					,"${view.job.run.schedule}":
						[0, "job.run_schedule"]
					,"${view.job.run.schedule.detail}":
						[0, "job.run_schedule_detail"]
					,"${view.job.forward.file}":
						[0, "job.forward_file"]
			}
			,"${maintenance}": {
				"${dialog.maintenance.list}":
					[1, "maintenance.list"]
			}
			,"${performance}": {
				"${view.performance.list}":
					[0, "performance.list"]
				,"${view.performance.recordedgraph}":
					[0, "performance.recordedgraph"]
				,"${view.performance.realtimegraph}":
					[0, "performance.realtimegraph"]
			}
		}*/
		/*Not used for version 1.0
		 * ,"${setupS}": {
			"${setup}":
				["openSetupDlg"]
		}
		,*/"${perspectiveP}": {
			"${open.perspective}":
				["openPersDlg"]
			/*Not used for version 1.0
			 * ,"${save.perspective}":
				["savePerspective"]*/
		}
//		,"${menu.view}": {
//			"${menu.monitor.event}":
//				["openEventView"]
//			,"${menu.monitor.status}":
//				["openHelpDlg"]
//			,"${menu.monitor.scope}":
//				["openHelpDlg"]
//		}
		,"${accesscontrolA}": {
			"${accesscontrol.login}":
				["login"]
			,"${accesscontrol.logout}":
				["logout"]
		}
		,"${menu.help}": {
			"${menu.help.about.web}":
				["openHelpDlg"]
		}
	};
};
